@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "dht.h"
 #include "announcereq.h"
 #include "announcersp.h"
@@ -47,11 +33,11 @@ using namespace bt;
 namespace dht
 {
 DHT::DHT()
-    : node(0)
-    , srv(0)
-    , db(0)
-    , tman(0)
-    , our_node_lookup(0)
+    : node(nullptr)
+    , srv(nullptr)
+    , db(nullptr)
+    , tman(nullptr)
+    , our_node_lookup(nullptr)
 {
     connect(&update_timer, &QTimer::timeout, this, &DHT::update);
     connect(&expire_timer, &QTimer::timeout, this, &DHT::expireDatabaseItems);
@@ -107,13 +93,13 @@ void DHT::stop()
     running = false;
     stopped();
     delete tman;
-    tman = 0;
+    tman = nullptr;
     delete db;
-    db = 0;
+    db = nullptr;
     delete node;
-    node = 0;
+    node = nullptr;
     delete srv;
-    srv = 0;
+    srv = nullptr;
 }
 
 void DHT::ping(const PingReq &r)
@@ -173,7 +159,7 @@ NodeLookup *DHT::findOwnNode()
 void DHT::ownNodeLookupFinished(Task *t)
 {
     if (our_node_lookup == t)
-        our_node_lookup = 0;
+        our_node_lookup = nullptr;
 }
 
 void DHT::announce(const AnnounceReq &r)
@@ -270,7 +256,7 @@ bool DHT::canStartTask() const
 AnnounceTask *DHT::announce(const bt::SHA1Hash &info_hash, bt::Uint16 port)
 {
     if (!running)
-        return 0;
+        return nullptr;
 
     KClosestNodesSearch kns(info_hash, K);
     node->findKClosestNodes(kns, WANT_BOTH);
@@ -284,13 +270,13 @@ AnnounceTask *DHT::announce(const bt::SHA1Hash &info_hash, bt::Uint16 port)
         return at;
     }
 
-    return 0;
+    return nullptr;
 }
 
 NodeLookup *DHT::refreshBucket(const dht::Key &id, KBucket &bucket)
 {
     if (!running)
-        return 0;
+        return nullptr;
 
     KClosestNodesSearch kns(id, K);
     bucket.findKClosestNodes(kns);
@@ -303,13 +289,13 @@ NodeLookup *DHT::refreshBucket(const dht::Key &id, KBucket &bucket)
         return nl;
     }
 
-    return 0;
+    return nullptr;
 }
 
 NodeLookup *DHT::findNode(const dht::Key &id)
 {
     if (!running)
-        return 0;
+        return nullptr;
 
     KClosestNodesSearch kns(id, K);
     node->findKClosestNodes(kns, WANT_BOTH);
@@ -321,7 +307,7 @@ NodeLookup *DHT::findNode(const dht::Key &id)
         return at;
     }
 
-    return 0;
+    return nullptr;
 }
 
 void DHT::expireDatabaseItems()
